Crate sos_integrity

Integrity checks for vaults, event logs and external files.

Enums

Error
Errors generated by the integrity library.
FileIntegrityEventfiles
Event dispatched whilst generating an integrity report.
FolderIntegrityEvent
Event dispatched whilst generating an integrity report.
IntegrityFailure
Reasons why an integrity check can fail.

Functions

account_integrity
Generate an integrity report for the folders in an account.
event_integrity
Integrity check for an event log comparing the precomputed checksums with the encrypted content of each row.
file_integrityfiles
Iterate a collection of external files and verify the integrity by checking the files exist on disc and the checksum of the disc contents matches the expected checksum.
vault_integrity
Integrity check for a vault file comparing the precomputed checksums with the encrypted content of each row.