pub enum Error {
Show 13 variants
VaultHashMismatch {
commit: CommitHash,
value: CommitHash,
id: Uuid,
},
HashMismatch {
commit: CommitHash,
value: CommitHash,
},
TryFromSlice(TryFromSliceError),
Core(Error),
Backend(Error),
Vault(Error),
FileSystem(Error),
Database(Error),
AsyncSqlite(Error),
Sqlite(Error),
Io(Error),
Uuid(Error),
Join(JoinError),
}Expand description
Errors generated by the integrity library.
Variants
VaultHashMismatch
Error generated when event log row data does not match the commit hash.
HashMismatch
Error generated when event log row data does not match the commit hash.
TryFromSlice(TryFromSliceError)
Error generated converting to fixed length slice.
Core(Error)
Error generated by the core library.
Backend(Error)
Error generated by the backend library.
Vault(Error)
Error generated by the vault library.
FileSystem(Error)
Error generated by the filesystem library.
Database(Error)
Error generated by the database library.
AsyncSqlite(Error)
Error generated by the sqlite library.
Sqlite(Error)
Error generated by the sqlite library.
Io(Error)
Error generated by the IO module.
Uuid(Error)
Error generated parsing UUIDs.
Join(JoinError)
Error generated when attempting to join a task.