Integrity checks for vaults, event logs and external files.
Enums
- Error
- Errors generated by the integrity library.
- File
Integrity Event files - Event dispatched whilst generating an integrity report.
- Folder
Integrity Event - Event dispatched whilst generating an integrity report.
- Integrity
Failure - Reasons why an integrity check can fail.
Functions
- account_
integrity - Generate an integrity report for the folders in an account.
- event_
integrity - Integrity check for an event log comparing the precomputed checksums with the encrypted content of each row.
- file_
integrity files - Iterate a collection of external files and verify the integrity by checking the files exist on disc and the checksum of the disc contents matches the expected checksum.
- vault_
integrity - Integrity check for a vault file comparing the precomputed checksums with the encrypted content of each row.